socsvn commit: r290051 - in soc2015/clord/head/sys/contrib/ficl: aarch64 amd64 arm mips mips64 powerpc sparc64

clord at FreeBSD.org clord at FreeBSD.org
Fri Aug 21 20:28:29 UTC 2015


Author: clord
Date: Fri Aug 21 20:28:22 2015
New Revision: 290051
URL: http://svnweb.FreeBSD.org/socsvn/?view=rev&rev=290051

Log:
  Replicate changes to sysdep files across all architectures.
  

Modified:
  soc2015/clord/head/sys/contrib/ficl/aarch64/sysdep.c
  soc2015/clord/head/sys/contrib/ficl/aarch64/sysdep.h
  soc2015/clord/head/sys/contrib/ficl/amd64/sysdep.c
  soc2015/clord/head/sys/contrib/ficl/arm/sysdep.c
  soc2015/clord/head/sys/contrib/ficl/arm/sysdep.h
  soc2015/clord/head/sys/contrib/ficl/mips/sysdep.c
  soc2015/clord/head/sys/contrib/ficl/mips/sysdep.h
  soc2015/clord/head/sys/contrib/ficl/mips64/sysdep.c
  soc2015/clord/head/sys/contrib/ficl/mips64/sysdep.h
  soc2015/clord/head/sys/contrib/ficl/powerpc/sysdep.c
  soc2015/clord/head/sys/contrib/ficl/powerpc/sysdep.h
  soc2015/clord/head/sys/contrib/ficl/sparc64/sysdep.c
  soc2015/clord/head/sys/contrib/ficl/sparc64/sysdep.h

Modified: soc2015/clord/head/sys/contrib/ficl/aarch64/sysdep.c
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/aarch64/sysdep.c	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/aarch64/sysdep.c	Fri Aug 21 20:28:22 2015	(r290051)
@@ -50,12 +50,12 @@
 }
 #endif
 
-void  ficlTextOut(FICL_VM *pVM, char *msg, int fNewline)
+void  ficlTextOutLocal(FICL_VM *pVM, char *text, int fNewline)
 {
     IGNORE(pVM);
 
-    while(*msg != 0)
-	putchar(*(msg++));
+    while(*text != 0)
+	putchar(*(text++));
     if (fNewline)
 	putchar('\n');
 

Modified: soc2015/clord/head/sys/contrib/ficl/aarch64/sysdep.h
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/amd64/sysdep.c	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/amd64/sysdep.c	Fri Aug 21 20:28:22 2015	(r290051)
@@ -50,12 +50,12 @@
 }
 #endif
 
-void  ficlTextOut(FICL_VM *pVM, char *msg, int fNewline)
+void  ficlTextOutLocal(FICL_VM *pVM, char *text, int fNewline)
 {
     IGNORE(pVM);
 
-    while(*msg != 0)
-	putchar(*(msg++));
+    while(*text != 0)
+	putchar(*(text++));
     if (fNewline)
 	putchar('\n');
 

Modified: soc2015/clord/head/sys/contrib/ficl/arm/sysdep.c
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/arm/sysdep.c	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/arm/sysdep.c	Fri Aug 21 20:28:22 2015	(r290051)
@@ -50,12 +50,12 @@
 }
 #endif
 
-void  ficlTextOut(FICL_VM *pVM, char *msg, int fNewline)
+void  ficlTextOutLocal(FICL_VM *pVM, char *text, int fNewline)
 {
     IGNORE(pVM);
 
-    while(*msg != 0)
-	putchar(*(msg++));
+    while(*text != 0)
+	putchar(*(text++));
     if (fNewline)
 	putchar('\n');
 

Modified: soc2015/clord/head/sys/contrib/ficl/arm/sysdep.h
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/mips/sysdep.c	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/mips/sysdep.c	Fri Aug 21 20:28:22 2015	(r290051)
@@ -50,12 +50,12 @@
 }
 #endif
 
-void  ficlTextOut(FICL_VM *pVM, char *msg, int fNewline)
+void  ficlTextOutLocal(FICL_VM *pVM, char *text, int fNewline)
 {
     IGNORE(pVM);
 
-    while(*msg != 0)
-	putchar(*(msg++));
+    while(*text != 0)
+	putchar(*(text++));
     if (fNewline)
 	putchar('\n');
 

Modified: soc2015/clord/head/sys/contrib/ficl/mips/sysdep.h
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/mips64/sysdep.c	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/mips64/sysdep.c	Fri Aug 21 20:28:22 2015	(r290051)
@@ -50,12 +50,12 @@
 }
 #endif
 
-void  ficlTextOut(FICL_VM *pVM, char *msg, int fNewline)
+void  ficlTextOutLocal(FICL_VM *pVM, char *text, int fNewline)
 {
     IGNORE(pVM);
 
-    while(*msg != 0)
-	putchar(*(msg++));
+    while(*text != 0)
+	putchar(*(text++));
     if (fNewline)
 	putchar('\n');
 

Modified: soc2015/clord/head/sys/contrib/ficl/mips64/sysdep.h
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/powerpc/sysdep.c	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/powerpc/sysdep.c	Fri Aug 21 20:28:22 2015	(r290051)
@@ -50,12 +50,12 @@
 }
 #endif
 
-void  ficlTextOut(FICL_VM *pVM, char *msg, int fNewline)
+void  ficlTextOutLocal(FICL_VM *pVM, char *text, int fNewline)
 {
     IGNORE(pVM);
 
-    while(*msg != 0)
-	putchar(*(msg++));
+    while(*text != 0)
+	putchar(*(text++));
     if (fNewline)
 	putchar('\n');
 

Modified: soc2015/clord/head/sys/contrib/ficl/powerpc/sysdep.h
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/sparc64/sysdep.c	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/sparc64/sysdep.c	Fri Aug 21 20:28:22 2015	(r290051)
@@ -50,12 +50,12 @@
 }
 #endif
 
-void  ficlTextOut(FICL_VM *pVM, char *msg, int fNewline)
+void  ficlTextOutLocal(FICL_VM *pVM, char *text, int fNewline)
 {
     IGNORE(pVM);
 
-    while(*msg != 0)
-	putchar(*(msg++));
+    while(*text != 0)
+	putchar(*(text++));
     if (fNewline)
 	putchar('\n');
 

Modified: soc2015/clord/head/sys/contrib/ficl/sparc64/sysdep.h
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/aarch64/sysdep.h	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/aarch64/sysdep.h	Fri Aug 21 20:28:22 2015	(r290051)
@@ -86,14 +86,6 @@
 #define UNS32 unsigned int
 #endif
 
-#if !defined UNS16
-#define UNS16 unsigned short
-#endif
-
-#if !defined UNS8
-#define UNS8 unsigned char
-#endif
-
 #if !defined NULL
 #define NULL ((void *)0)
 #endif
@@ -102,7 +94,6 @@
 ** FICL_UNS and FICL_INT must have the same size as a void* on
 ** the target system. A CELL is a union of void*, FICL_UNS, and
 ** FICL_INT. 
-** (11/2000: same for FICL_FLOAT)
 */
 #if !defined FICL_INT
 #define FICL_INT long
@@ -112,10 +103,6 @@
 #define FICL_UNS unsigned long
 #endif
 
-#if !defined FICL_FLOAT
-#define FICL_FLOAT float
-#endif
-
 /*
 ** Ficl presently supports values of 32 and 64 for BITS_PER_CELL
 */
@@ -186,7 +173,7 @@
 ** Contributed by Guy Carver
 */
 #if !defined (FICL_WANT_FLOAT)
-#define FICL_WANT_FLOAT 0
+#define FICL_WANT_FLOAT 1
 #endif
 
 /*
@@ -301,8 +288,8 @@
 ** a new virtual machine's stacks, unless overridden at 
 ** create time.
 */
-#if !defined FICL_DEFAULT_STACK
-#define FICL_DEFAULT_STACK 128
+#if !defined FICL_DEFAULT_STACK_SIZE
+#define FICL_DEFAULT_STACK_SIZE 128
 #endif
 
 /*
@@ -312,12 +299,12 @@
 ** FICL_DEFAULT_ENV specifies the number of cells to allot
 ** for the environment-query dictionary.
 */
-#if !defined FICL_DEFAULT_DICT
-#define FICL_DEFAULT_DICT 12288
+#if !defined FICL_DEFAULT_DICTIONARY_SIZE
+#define FICL_DEFAULT_DICTIONARY_SIZE 12288
 #endif
 
-#if !defined FICL_DEFAULT_ENV
-#define FICL_DEFAULT_ENV 260
+#if !defined FICL_DEFAULT_ENVIRONMENT_SIZE
+#define FICL_DEFAULT_ENVIRONMENT_SIZE 260
 #endif
 
 /*
@@ -325,8 +312,8 @@
 ** the dictionary search order. See Forth DPANS sec 16.3.3
 ** (file://dpans16.htm#16.3.3)
 */
-#if !defined FICL_DEFAULT_VOCS
-#define FICL_DEFAULT_VOCS 16
+#if !defined FICL_MAX_WORDLISTS
+#define FICL_MAX_WORDLISTS 16
 #endif
 
 /*
@@ -363,7 +350,7 @@
 ** System dependent routines --
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
 ** ficlTextOut sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free
 **   in standard C
@@ -373,7 +360,7 @@
 **   and remainder
 */
 struct vm;
-void  ficlTextOut(struct vm *pVM, char *msg, int fNewline);
+void  ficlTextOutLocal(struct vm *pVM, char *text, int fNewline);
 void *ficlMalloc (size_t size);
 void  ficlFree   (void *p);
 void *ficlRealloc(void *p, size_t size);
@@ -405,7 +392,16 @@
 ** on a 32 bit CPU than in C, which usually doesn't support 
 ** the double length result (but it should).
 */
+#ifndef __SYSDEP_H__
 DPUNS ficlLongMul(FICL_UNS x, FICL_UNS y);
 UNSQR ficlLongDiv(DPUNS    q, FICL_UNS y);
+#endif
+
+/*
+** Remove old definitions to remove conflicts with ficlcompatibility.h
+** in case FICL_WANT_COMPATIBILITY is set.
+*/
+#undef FICL_UNS
+#undef FICL_INT
 
 #endif /*__SYSDEP_H__*/
@@ -363,7 +350,7 @@
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
-** ficlTextOut sends a NULL terminated string to the 
+** ficlTextOutLocal sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free

Modified: soc2015/clord/head/sys/contrib/ficl/amd64/sysdep.c
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/arm/sysdep.h	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/arm/sysdep.h	Fri Aug 21 20:28:22 2015	(r290051)
@@ -86,14 +86,6 @@
 #define UNS32 unsigned int
 #endif
 
-#if !defined UNS16
-#define UNS16 unsigned short
-#endif
-
-#if !defined UNS8
-#define UNS8 unsigned char
-#endif
-
 #if !defined NULL
 #define NULL ((void *)0)
 #endif
@@ -102,7 +94,6 @@
 ** FICL_UNS and FICL_INT must have the same size as a void* on
 ** the target system. A CELL is a union of void*, FICL_UNS, and
 ** FICL_INT. 
-** (11/2000: same for FICL_FLOAT)
 */
 #if !defined FICL_INT
 #define FICL_INT INT32
@@ -112,10 +103,6 @@
 #define FICL_UNS UNS32
 #endif
 
-#if !defined FICL_FLOAT
-#define FICL_FLOAT float
-#endif
-
 /*
 ** Ficl presently supports values of 32 and 64 for BITS_PER_CELL
 */
@@ -197,7 +184,7 @@
 ** Contributed by Guy Carver
 */
 #if !defined (FICL_WANT_FLOAT)
-#define FICL_WANT_FLOAT 0
+#define FICL_WANT_FLOAT 1
 #endif
 
 /*
@@ -312,8 +299,8 @@
 ** a new virtual machine's stacks, unless overridden at 
 ** create time.
 */
-#if !defined FICL_DEFAULT_STACK
-#define FICL_DEFAULT_STACK 128
+#if !defined FICL_DEFAULT_STACK_SIZE
+#define FICL_DEFAULT_STACK_SIZE 128
 #endif
 
 /*
@@ -323,12 +310,12 @@
 ** FICL_DEFAULT_ENV specifies the number of cells to allot
 ** for the environment-query dictionary.
 */
-#if !defined FICL_DEFAULT_DICT
-#define FICL_DEFAULT_DICT 12288
+#if !defined FICL_DEFAULT_DICTIONARY_SIZE
+#define FICL_DEFAULT_DICTIONARY_SIZE 12288
 #endif
 
-#if !defined FICL_DEFAULT_ENV
-#define FICL_DEFAULT_ENV 260
+#if !defined FICL_DEFAULT_ENVIRONMENT_SIZE
+#define FICL_DEFAULT_ENVIRONMENT_SIZE 260
 #endif
 
 /*
@@ -336,8 +323,8 @@
 ** the dictionary search order. See Forth DPANS sec 16.3.3
 ** (file://dpans16.htm#16.3.3)
 */
-#if !defined FICL_DEFAULT_VOCS
-#define FICL_DEFAULT_VOCS 16
+#if !defined FICL_MAX_WORDLISTS
+#define FICL_MAX_WORDLISTS 16
 #endif
 
 /*
@@ -374,7 +361,7 @@
 ** System dependent routines --
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
 ** ficlTextOut sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free
 **   in standard C
@@ -384,7 +371,7 @@
 **   and remainder
 */
 struct vm;
-void  ficlTextOut(struct vm *pVM, char *msg, int fNewline);
+void  ficlTextOutLocal(struct vm *pVM, char *text, int fNewline);
 void *ficlMalloc (size_t size);
 void  ficlFree   (void *p);
 void *ficlRealloc(void *p, size_t size);
@@ -416,8 +403,10 @@
 ** on a 32 bit CPU than in C, which usually doesn't support 
 ** the double length result (but it should).
 */
+#ifndef __SYSDEP_H__
 DPUNS ficlLongMul(FICL_UNS x, FICL_UNS y);
 UNSQR ficlLongDiv(DPUNS    q, FICL_UNS y);
+#endif
 
 /*
 ** FICL_HAVE_FTRUNCATE indicates whether the current OS supports
@@ -428,5 +417,11 @@
 #define FICL_HAVE_FTRUNCATE 0
 #endif
 
+/*
+** Remove old definitions to remove conflicts with ficlcompatibility.h
+** in case FICL_WANT_COMPATIBILITY is set.
+*/
+#undef FICL_UNS
+#undef FICL_INT
 
 #endif /*__SYSDEP_H__*/
@@ -374,7 +361,7 @@
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
-** ficlTextOut sends a NULL terminated string to the 
+** ficlTextOutLocal sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free

Modified: soc2015/clord/head/sys/contrib/ficl/mips/sysdep.c
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/mips/sysdep.h	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/mips/sysdep.h	Fri Aug 21 20:28:22 2015	(r290051)
@@ -86,14 +86,6 @@
 #define UNS32 unsigned int
 #endif
 
-#if !defined UNS16
-#define UNS16 unsigned short
-#endif
-
-#if !defined UNS8
-#define UNS8 unsigned char
-#endif
-
 #if !defined NULL
 #define NULL ((void *)0)
 #endif
@@ -102,7 +94,6 @@
 ** FICL_UNS and FICL_INT must have the same size as a void* on
 ** the target system. A CELL is a union of void*, FICL_UNS, and
 ** FICL_INT. 
-** (11/2000: same for FICL_FLOAT)
 */
 #if !defined FICL_INT
 #define FICL_INT INT32
@@ -112,10 +103,6 @@
 #define FICL_UNS UNS32
 #endif
 
-#if !defined FICL_FLOAT
-#define FICL_FLOAT float
-#endif
-
 /*
 ** Ficl presently supports values of 32 and 64 for BITS_PER_CELL
 */
@@ -197,7 +184,7 @@
 ** Contributed by Guy Carver
 */
 #if !defined (FICL_WANT_FLOAT)
-#define FICL_WANT_FLOAT 0
+#define FICL_WANT_FLOAT 1
 #endif
 
 /*
@@ -312,8 +299,8 @@
 ** a new virtual machine's stacks, unless overridden at 
 ** create time.
 */
-#if !defined FICL_DEFAULT_STACK
-#define FICL_DEFAULT_STACK 128
+#if !defined FICL_DEFAULT_STACK_SIZE
+#define FICL_DEFAULT_STACK_SIZE 128
 #endif
 
 /*
@@ -323,12 +310,12 @@
 ** FICL_DEFAULT_ENV specifies the number of cells to allot
 ** for the environment-query dictionary.
 */
-#if !defined FICL_DEFAULT_DICT
-#define FICL_DEFAULT_DICT 12288
+#if !defined FICL_DEFAULT_DICTIONARY_SIZE
+#define FICL_DEFAULT_DICTIONARY_SIZE 12288
 #endif
 
-#if !defined FICL_DEFAULT_ENV
-#define FICL_DEFAULT_ENV 260
+#if !defined FICL_DEFAULT_ENVIRONMENT_SIZE
+#define FICL_DEFAULT_ENVIRONMENT_SIZE 260
 #endif
 
 /*
@@ -336,8 +323,8 @@
 ** the dictionary search order. See Forth DPANS sec 16.3.3
 ** (file://dpans16.htm#16.3.3)
 */
-#if !defined FICL_DEFAULT_VOCS
-#define FICL_DEFAULT_VOCS 16
+#if !defined FICL_MAX_WORDLISTS
+#define FICL_MAX_WORDLISTS 16
 #endif
 
 /*
@@ -374,7 +361,7 @@
 ** System dependent routines --
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
 ** ficlTextOut sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free
 **   in standard C
@@ -384,7 +371,7 @@
 **   and remainder
 */
 struct vm;
-void  ficlTextOut(struct vm *pVM, char *msg, int fNewline);
+void  ficlTextOutLocal(struct vm *pVM, char *text, int fNewline);
 void *ficlMalloc (size_t size);
 void  ficlFree   (void *p);
 void *ficlRealloc(void *p, size_t size);
@@ -416,8 +403,10 @@
 ** on a 32 bit CPU than in C, which usually doesn't support 
 ** the double length result (but it should).
 */
+#ifndef __SYSDEP_H__
 DPUNS ficlLongMul(FICL_UNS x, FICL_UNS y);
 UNSQR ficlLongDiv(DPUNS    q, FICL_UNS y);
+#endif
 
 /*
 ** FICL_HAVE_FTRUNCATE indicates whether the current OS supports
@@ -428,5 +417,11 @@
 #define FICL_HAVE_FTRUNCATE 0
 #endif
 
+/*
+** Remove old definitions to remove conflicts with ficlcompatibility.h
+** in case FICL_WANT_COMPATIBILITY is set.
+*/
+#undef FICL_UNS
+#undef FICL_INT
 
 #endif /*__SYSDEP_H__*/
@@ -374,7 +361,7 @@
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
-** ficlTextOut sends a NULL terminated string to the 
+** ficlTextOutLocal sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free

Modified: soc2015/clord/head/sys/contrib/ficl/mips64/sysdep.c
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/mips64/sysdep.h	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/mips64/sysdep.h	Fri Aug 21 20:28:22 2015	(r290051)
@@ -86,14 +86,6 @@
 #define UNS32 unsigned int
 #endif
 
-#if !defined UNS16
-#define UNS16 unsigned short
-#endif
-
-#if !defined UNS8
-#define UNS8 unsigned char
-#endif
-
 #if !defined NULL
 #define NULL ((void *)0)
 #endif
@@ -102,7 +94,6 @@
 ** FICL_UNS and FICL_INT must have the same size as a void* on
 ** the target system. A CELL is a union of void*, FICL_UNS, and
 ** FICL_INT. 
-** (11/2000: same for FICL_FLOAT)
 */
 #if !defined FICL_INT
 #define FICL_INT long
@@ -112,10 +103,6 @@
 #define FICL_UNS unsigned long
 #endif
 
-#if !defined FICL_FLOAT
-#define FICL_FLOAT float
-#endif
-
 /*
 ** Ficl presently supports values of 32 and 64 for BITS_PER_CELL
 */
@@ -197,7 +184,7 @@
 ** Contributed by Guy Carver
 */
 #if !defined (FICL_WANT_FLOAT)
-#define FICL_WANT_FLOAT 0
+#define FICL_WANT_FLOAT 1
 #endif
 
 /*
@@ -312,8 +299,8 @@
 ** a new virtual machine's stacks, unless overridden at 
 ** create time.
 */
-#if !defined FICL_DEFAULT_STACK
-#define FICL_DEFAULT_STACK 128
+#if !defined FICL_DEFAULT_STACK_SIZE
+#define FICL_DEFAULT_STACK_SIZE 128
 #endif
 
 /*
@@ -323,12 +310,12 @@
 ** FICL_DEFAULT_ENV specifies the number of cells to allot
 ** for the environment-query dictionary.
 */
-#if !defined FICL_DEFAULT_DICT
-#define FICL_DEFAULT_DICT 12288
+#if !defined FICL_DEFAULT_DICTIONARY_SIZE
+#define FICL_DEFAULT_DICTIONARY_SIZE 12288
 #endif
 
-#if !defined FICL_DEFAULT_ENV
-#define FICL_DEFAULT_ENV 260
+#if !defined FICL_DEFAULT_ENVIRONMENT_SIZE
+#define FICL_DEFAULT_ENVIRONMENT_SIZE 260
 #endif
 
 /*
@@ -336,8 +323,8 @@
 ** the dictionary search order. See Forth DPANS sec 16.3.3
 ** (file://dpans16.htm#16.3.3)
 */
-#if !defined FICL_DEFAULT_VOCS
-#define FICL_DEFAULT_VOCS 16
+#if !defined FICL_MAX_WORDLISTS
+#define FICL_MAX_WORDLISTS 16
 #endif
 
 /*
@@ -374,7 +361,7 @@
 ** System dependent routines --
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
 ** ficlTextOut sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free
 **   in standard C
@@ -384,7 +371,7 @@
 **   and remainder
 */
 struct vm;
-void  ficlTextOut(struct vm *pVM, char *msg, int fNewline);
+void  ficlTextOutLocal(struct vm *pVM, char *text, int fNewline);
 void *ficlMalloc (size_t size);
 void  ficlFree   (void *p);
 void *ficlRealloc(void *p, size_t size);
@@ -416,8 +403,10 @@
 ** on a 32 bit CPU than in C, which usually doesn't support 
 ** the double length result (but it should).
 */
+#ifndef __SYSDEP_H__
 DPUNS ficlLongMul(FICL_UNS x, FICL_UNS y);
 UNSQR ficlLongDiv(DPUNS    q, FICL_UNS y);
+#endif
 
 /*
 ** FICL_HAVE_FTRUNCATE indicates whether the current OS supports
@@ -428,5 +417,11 @@
 #define FICL_HAVE_FTRUNCATE 0
 #endif
 
+/*
+** Remove old definitions to remove conflicts with ficlcompatibility.h
+** in case FICL_WANT_COMPATIBILITY is set.
+*/
+#undef FICL_UNS
+#undef FICL_INT
 
 #endif /*__SYSDEP_H__*/
@@ -374,7 +361,7 @@
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
-** ficlTextOut sends a NULL terminated string to the 
+** ficlTextOutLocal sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free

Modified: soc2015/clord/head/sys/contrib/ficl/powerpc/sysdep.c
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/powerpc/sysdep.h	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/powerpc/sysdep.h	Fri Aug 21 20:28:22 2015	(r290051)
@@ -86,14 +86,6 @@
 #define UNS32 unsigned int
 #endif
 
-#if !defined UNS16
-#define UNS16 unsigned short
-#endif
-
-#if !defined UNS8
-#define UNS8 unsigned char
-#endif
-
 #if !defined NULL
 #define NULL ((void *)0)
 #endif
@@ -102,7 +94,6 @@
 ** FICL_UNS and FICL_INT must have the same size as a void* on
 ** the target system. A CELL is a union of void*, FICL_UNS, and
 ** FICL_INT. 
-** (11/2000: same for FICL_FLOAT)
 */
 #if !defined FICL_INT
 #define FICL_INT INT32
@@ -112,10 +103,6 @@
 #define FICL_UNS UNS32
 #endif
 
-#if !defined FICL_FLOAT
-#define FICL_FLOAT float
-#endif
-
 /*
 ** Ficl presently supports values of 32 and 64 for BITS_PER_CELL
 */
@@ -197,7 +184,7 @@
 ** Contributed by Guy Carver
 */
 #if !defined (FICL_WANT_FLOAT)
-#define FICL_WANT_FLOAT 0
+#define FICL_WANT_FLOAT 1
 #endif
 
 /*
@@ -312,8 +299,8 @@
 ** a new virtual machine's stacks, unless overridden at 
 ** create time.
 */
-#if !defined FICL_DEFAULT_STACK
-#define FICL_DEFAULT_STACK 128
+#if !defined FICL_DEFAULT_STACK_SIZE
+#define FICL_DEFAULT_STACK_SIZE 128
 #endif
 
 /*
@@ -323,12 +310,12 @@
 ** FICL_DEFAULT_ENV specifies the number of cells to allot
 ** for the environment-query dictionary.
 */
-#if !defined FICL_DEFAULT_DICT
-#define FICL_DEFAULT_DICT 12288
+#if !defined FICL_DEFAULT_DICTIONARY_SIZE
+#define FICL_DEFAULT_DICTIONARY_SIZE 12288
 #endif
 
-#if !defined FICL_DEFAULT_ENV
-#define FICL_DEFAULT_ENV 260
+#if !defined FICL_DEFAULT_ENVIRONMENT_SIZE
+#define FICL_DEFAULT_ENVIRONMENT_SIZE 260
 #endif
 
 /*
@@ -336,8 +323,8 @@
 ** the dictionary search order. See Forth DPANS sec 16.3.3
 ** (file://dpans16.htm#16.3.3)
 */
-#if !defined FICL_DEFAULT_VOCS
-#define FICL_DEFAULT_VOCS 16
+#if !defined FICL_MAX_WORDLISTS
+#define FICL_MAX_WORDLISTS 16
 #endif
 
 /*
@@ -374,7 +361,7 @@
 ** System dependent routines --
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
 ** ficlTextOut sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free
 **   in standard C
@@ -384,7 +371,7 @@
 **   and remainder
 */
 struct vm;
-void  ficlTextOut(struct vm *pVM, char *msg, int fNewline);
+void  ficlTextOutLocal(struct vm *pVM, char *text, int fNewline);
 void *ficlMalloc (size_t size);
 void  ficlFree   (void *p);
 void *ficlRealloc(void *p, size_t size);
@@ -416,8 +403,10 @@
 ** on a 32 bit CPU than in C, which usually doesn't support 
 ** the double length result (but it should).
 */
+#ifndef __SYSDEP_H__
 DPUNS ficlLongMul(FICL_UNS x, FICL_UNS y);
 UNSQR ficlLongDiv(DPUNS    q, FICL_UNS y);
+#endif
 
 /*
 ** FICL_HAVE_FTRUNCATE indicates whether the current OS supports
@@ -428,5 +417,11 @@
 #define FICL_HAVE_FTRUNCATE 0
 #endif
 
+/*
+** Remove old definitions to remove conflicts with ficlcompatibility.h
+** in case FICL_WANT_COMPATIBILITY is set.
+*/
+#undef FICL_UNS
+#undef FICL_INT
 
 #endif /*__SYSDEP_H__*/
@@ -374,7 +361,7 @@
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
-** ficlTextOut sends a NULL terminated string to the 
+** ficlTextOutLocal sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free

Modified: soc2015/clord/head/sys/contrib/ficl/sparc64/sysdep.c
==============================================================================
--- soc2015/clord/head/sys/contrib/ficl/sparc64/sysdep.h	Fri Aug 21 19:51:27 2015	(r290050)
+++ soc2015/clord/head/sys/contrib/ficl/sparc64/sysdep.h	Fri Aug 21 20:28:22 2015	(r290051)
@@ -87,14 +87,6 @@
 #define UNS32 unsigned int
 #endif
 
-#if !defined UNS16
-#define UNS16 unsigned short
-#endif
-
-#if !defined UNS8
-#define UNS8 unsigned char
-#endif
-
 #if !defined NULL
 #define NULL ((void *)0)
 #endif
@@ -103,7 +95,6 @@
 ** FICL_UNS and FICL_INT must have the same size as a void* on
 ** the target system. A CELL is a union of void*, FICL_UNS, and
 ** FICL_INT. 
-** (11/2000: same for FICL_FLOAT)
 */
 #if !defined FICL_INT
 #define FICL_INT long
@@ -113,10 +104,6 @@
 #define FICL_UNS unsigned long
 #endif
 
-#if !defined FICL_FLOAT
-#define FICL_FLOAT float
-#endif
-
 /*
 ** Ficl presently supports values of 32 and 64 for BITS_PER_CELL
 */
@@ -187,7 +174,7 @@
 ** Contributed by Guy Carver
 */
 #if !defined (FICL_WANT_FLOAT)
-#define FICL_WANT_FLOAT 0
+#define FICL_WANT_FLOAT 1
 #endif
 
 /*
@@ -302,8 +289,8 @@
 ** a new virtual machine's stacks, unless overridden at 
 ** create time.
 */
-#if !defined FICL_DEFAULT_STACK
-#define FICL_DEFAULT_STACK 128
+#if !defined FICL_DEFAULT_STACK_SIZE
+#define FICL_DEFAULT_STACK_SIZE 128
 #endif
 
 /*
@@ -313,12 +300,12 @@
 ** FICL_DEFAULT_ENV specifies the number of cells to allot
 ** for the environment-query dictionary.
 */
-#if !defined FICL_DEFAULT_DICT
-#define FICL_DEFAULT_DICT 12288
+#if !defined FICL_DEFAULT_DICTIONARY_SIZE
+#define FICL_DEFAULT_DICTIONARY_SIZE 12288
 #endif
 
-#if !defined FICL_DEFAULT_ENV
-#define FICL_DEFAULT_ENV 260
+#if !defined FICL_DEFAULT_ENVIRONMENT_SIZE
+#define FICL_DEFAULT_ENVIRONMENT_SIZE 260
 #endif
 
 /*
@@ -326,8 +313,8 @@
 ** the dictionary search order. See Forth DPANS sec 16.3.3
 ** (file://dpans16.htm#16.3.3)
 */
-#if !defined FICL_DEFAULT_VOCS
-#define FICL_DEFAULT_VOCS 16
+#if !defined FICL_MAX_WORDLISTS
+#define FICL_MAX_WORDLISTS 16
 #endif
 
 /*
@@ -364,7 +351,7 @@
 ** System dependent routines --
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
 ** ficlTextOut sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free
 **   in standard C
@@ -374,7 +361,7 @@
 **   and remainder
 */
 struct vm;
-void  ficlTextOut(struct vm *pVM, char *msg, int fNewline);
+void  ficlTextOutLocal(struct vm *pVM, char *text, int fNewline);
 void *ficlMalloc (size_t size);
 void  ficlFree   (void *p);
 void *ficlRealloc(void *p, size_t size);
@@ -406,7 +393,16 @@
 ** on a 32 bit CPU than in C, which usually doesn't support 
 ** the double length result (but it should).
 */
+#ifndef __SYSDEP_H__
 DPUNS ficlLongMul(FICL_UNS x, FICL_UNS y);
 UNSQR ficlLongDiv(DPUNS    q, FICL_UNS y);
+#endif
 
+/*
+** Remove old definitions to remove conflicts with ficlcompatibility.h
+** in case FICL_WANT_COMPATIBILITY is set.
+*/
+#undef FICL_UNS
+#undef FICL_INT
+ 
 #endif /*__SYSDEP_H__*/
@@ -364,7 +351,7 @@
 ** edit the implementations in sysdep.c to be compatible
 ** with your runtime environment...
-** ficlTextOut sends a NULL terminated string to the 
+** ficlTextOutLocal sends a NULL terminated string to the 
 **   default output device - used for system error messages
 ** ficlMalloc and ficlFree have the same semantics as malloc and free


More information about the svn-soc-all mailing list